<?php
/**
*
* acp_board.php [Sorani Kurdish]
*
* @package language
* @version $Id: $
* @copyright (c) 2009 phpBB Group
* @author 2009-05-30 - Chawg.org Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ACP_BOARD_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانی کرداری بنچینەی مەکۆکەت دیاریبکەی ،ناوێکی گونجاو بدە لەگەڵ باسکردن ، وە هەندێ ڕێکخستنی تری نرخە بنەڕەتەکان بۆ کاتی ناوچەیی لەگەڵ زمان.',
	'CUSTOM_DATEFORMAT'	=> 'دەستکرد...',
	'DEFAULT_DATE_FORMAT'	=> 'شێوازی ڕێکەوت',
	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'جۆری بەروار هەمانە جۆرە وەکو لە نەخشەی PHP <code>date</code>.',
	'DEFAULT_LANGUAGE'	=> 'زمانی بنەڕەت',
	'DEFAULT_STYLE'	=> 'ڕووخساری بنەڕەت',
	'DISABLE_BOARD'	=> 'ناچالاککردنی مەکۆ',
	'DISABLE_BOARD_EXPLAIN'	=> 'ئەوە مەکۆکە بێ-بەردەست دەکات بۆ بەکارهێنەران. هەروەها دەتوانی پەیامێکی کورت بنووسی بۆ نیشاندان ئەگەر ویستت.',
	'OVERRIDE_STYLE'	=> 'هەڵوەشاندنەوەی شێوازی بەکارهێنەر',
	'OVERRIDE_STYLE_EXPLAIN'	=> 'شێوازی بەکارهێەر لەگەڵ بنەڕەت دابنێوە',
	'SITE_DESC'	=> 'پەسنی ماڵپەڕ',
	'SITE_NAME'	=> 'ناوی ماڵپەڕ',
	'SYSTEM_DST'	=> 'چالاککردنی کاتی هاوینە/<abbr title="Daylight Saving Time">DST</abbr>',
	'SYSTEM_TIMEZONE'				=> 'کاتی ناوچەیی میوان',
	'SYSTEM_TIMEZONE_EXPLAIN'			=> 'کاتی ناوچەیی بۆ نیشاندانی کاتەکان بۆ ئەو بەکارهێنەرانەی کە لە ژوورەوە نین (میوانەکان، بووتەکان). ئەو بەکارهێنەرانەی لە ژوورەوەن لەکاتی تۆماربووندا کاتی ناوچەییان داناوە و دەشتوانن بیگۆڕن لە کۆنترۆڵ پانێڵی خۆیان.',
	'WARNINGS_EXPIRE'	=> 'ماوەی ئاگاداری',
	'WARNINGS_EXPIRE_EXPLAIN'	=> 'ژمارەی ڕۆژەکان کە ڕزگاری دەبێت پێ ئاگادارکردنەوە ،خۆکارانە لە تۆماری بەکارهێنەر بەسەردەچێت. ئەو نرخە بە 0 دابنێ بۆ دانانی بە هەمیشەیی.',
	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'لێرە دەتوانیت چەندین تایبەتمەندی مەکۆ چالاک/ناچالاک بکەیت.',
	'ALLOW_ATTACHMENTS'	=> 'ڕێدان هاوپێچ',
	'ALLOW_BIRTHDAYS'	=> 'ڕێدان بە ڕۆژی لە دایکبوون',
	'ALLOW_BIRTHDAYS_EXPLAIN'	=> 'ڕێگابدە بە ڕۆژی لەدایکبوون بۆ ئەوەی بنووسرێ لەگەڵ تەمەن بۆ ئەوەی نیشانبدرێ لە پرۆفایلەکان. تکایە سەرنجبدە لیستی ڕۆژی لەدایکبوون لەناو پێڕستی مەکۆکە دەستی بەسەرداگیراوە لەلایەن ڕێکخستنێکی جیای بارکردن.',
	'ALLOW_BOOKMARKS'	=> 'ڕێدان بە دڵخوازکردنی بابەتەکان',
	'ALLOW_BOOKMARKS_EXPLAIN'	=> 'بەکارهێنەر توانای پاشەکەوتکردنی دڵخوازی تایبەتیی هەیە.',
	'ALLOW_BBCODE'	=> 'ڕێدان بە BBCode',
	'ALLOW_FORUM_NOTIFY'	=> 'ڕێدان بە بەشداربوون لە مەکۆکان',
	'ALLOW_NAME_CHANGE'	=> 'ڕێدان بە گۆڕینی ناوی بەکارهێنەر',
	'ALLOW_NO_CENSORS'	=> 'ڕێگا بە ناچالاککردنی سانسۆرکردنی وشە بدە',
	'ALLOW_NO_CENSORS_EXPLAIN'	=> 'بەکارهێنەران دەتوانن سانسۆرکردنی خۆکاریی وشە ناچالاک بکەن لە پەیامەکان و پەیامە تایبەتییەکان.',
	'ALLOW_PM_ATTACHMENTS'	=> 'ڕێدان بە هاوپێچ لە پەیامی تایبەت',
	'ALLOW_PM_REPORT'			=> 'ڕێدان بە بەکارهێنەران بۆ ڕاپۆرتکردنی پەیامی تایبەت',
	'ALLOW_PM_REPORT_EXPLAIN'	=> 'گەر ئەم ڕێکخستنە چالاک بکرێت، توانای ڕاپۆرتکردنی پەیامی تایبەتییان دەبێت کە پێیان گەیشتووە یان نێردراوە بۆ چاودێرانی مەکۆ. دواتر ئەو پەیامە تایبەتییانە دەبینرێن لە کۆنتڕۆڵ پانێڵی چاودێردا.',
	'ALLOW_QUICK_REPLY'			=> 'ڕێ بە وەڵامدانەوەی خێرا بدە',
	'ALLOW_QUICK_REPLY_EXPLAIN'	=> 'ئەم ڕێکخستنە ئەوە دیاری دەکات ئەگەر پەیامی خێرا چالاک کراوە یان نا. ئەگەر چالاک کرابێت، پێویستە هەڵژاردنی پەیامنووسینی خێرای مەکۆکانیش چالاک کرابێت.',
	'ALLOW_QUICK_REPLY_BUTTON'	=> 'ڕێگەدان بەوەڵمدانەوەی خێرا لە هەموو مەکۆکان',
	'ALLOW_SIG'	=> 'ڕێدان بە واژۆ',
	'ALLOW_SIG_BBCODE'	=> 'ڕێدان بە BBCode لە واژۆی ئەندام',
	'ALLOW_SIG_FLASH'	=> 'ڕێگابدە بە بەکاربردنی تاگی <code>[FLASH]</code> لە واژۆی بەکارهێنەران.',
	'ALLOW_SIG_IMG'	=> 'ڕێگابدە بە بەکاربردنی تاگی <code>[IMG]</code> لە واژۆی بەکارهێنەران',
	'ALLOW_SIG_LINKS'	=> 'ڕێگابدە بە بەکاربردنی بەستەر لە واژۆی بەکارهێنەران',
	'ALLOW_SIG_LINKS_EXPLAIN'	=> 'ئەگەر تاگی <code>[URL]</code> ناچالاککرد ئەوا URL‌ ــی خۆکاری/جادوو ناچالاک دەکەیت لەگەڵی.',
	'ALLOW_SIG_SMILIES'	=> 'ڕێدان بە خەندە لە واژۆی بەکارهێنەران',
	'ALLOW_SMILIES'	=> 'ڕێدان بە خەندەکان',
	'ALLOW_TOPIC_NOTIFY'	=> 'ڕێدان بە بەشداربوون لە بابەتەکان',
	'BOARD_PM'	=> 'پەیامی تایبەت',
	'BOARD_PM_EXPLAIN'			=> 'پەیامی تایبەت بۆ هەموو بەکارهێنەران چالاکبکە',
	'ACP_AVATAR_SETTINGS_EXPLAIN'	=> 'وێنۆچکەکان بەگشتی بچووکن، وێنەیەکە بەکارهێنەر دەتوانێ خۆی دیاریبکات بەپێی شێوازی دانراو. بەزۆری وێنۆچکە لەخوا ناوی بەکارهێنەر نیشاندەدرێت لەکاتی بینینی بابەتەکان. لێرە دەتوانی دیاریبکەی کە چۆن بەکارهێنەران وێنۆچکەکانیان پێناسەبکەن. تکایە سەرنجبدە کە بۆ بارکردنی وێنۆچکەکان پێویستە پێڕست/شوێنگە دروست کردبێت و دڵنیابیت کە دەتوانرێ بۆی بنووسرێت لەلایەن ڕاژەکاری وێب. هەروەها سەرنجی ئەوەش بدە کە سنوورەکانی قەبارەی پەڕگە تەنها بەکارە لەسەر وێنۆچکە بارکراوەکان، لەسەر وێنە بەستەر بۆ کراوەکان ناچەسپێنرێن.',
	'ALLOW_AVATARS'					=> 'چالاککردنی وێنۆچکە',
	'ALLOW_AVATARS_EXPLAIN'			=> 'ڕێگابدە بە بەکاربردنی گشتی وێنۆچکە؛<br />ئەگەر وێنۆچکەکان ناچالاک بکەیت لە گشتیدا یان وێنۆچکەکان لە بارێکدا، وێنۆچکە ناچالاک کراوەکان هیچی تر بەدیارناکەون لەسەر مەکۆکە، بەڵام بەکارهێنەران هێشتا دەتوانن وێنۆچکەکانی خۆیان دابگرن لە کۆنترۆڵ پانێڵی بەکارهێنەر.',
	'ALLOW_LOCAL'	=> 'گەلەریی وێنۆچکەکان چالاک بکە',
	'ALLOW_REMOTE'	=> 'وێنۆچکە دەست بەسەرەکان چالاکبکە.',
	'ALLOW_REMOTE_EXPLAIN'	=> 'وێنۆچکەکان بەستەرکراون لە وێبگەیەکی تر.',
	'ALLOW_REMOTE_UPLOAD'			=> 'بارکردنی وێنۆچکە دەست بەسەرەکان چالاکبکە',
	'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'ڕێگادان بە بارکردنی وێنۆچکە لە وێبگەیەکی ترەوە.',
	'ALLOW_UPLOAD'	=> 'بارکردنی وێنۆچکە چالاکبکە',
	'AVATAR_GALLERY_PATH'	=> 'ڕێڕەوی گەلەریی وێنۆچکە',
	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'ڕێچکە لەژێر سەرەتای پێڕستی phpBB ــیت بۆ وێنە بەکار-بارکاوەکان، نموونە <samp>images/avatars/gallery</samp>.',
	'AVATAR_STORAGE_PATH'	=> 'ڕێچکەی کۆگای وێنۆچکە',
	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'ڕێچکە لەژێر سەرەتای پێڕستی phpBB ــیت نموونە  <samp>images/avatars/upload</samp>.',
	'MAX_AVATAR_SIZE'	=> 'زۆرترین دوورییەکانی وێنە',
	'MAX_AVATAR_SIZE_EXPLAIN'	=> 'پانی x بەرزی بە خاڵ.',
	'MAX_FILESIZE'	=> 'زۆرترین قەبارەی وێنۆچکە',
	'MAX_FILESIZE_EXPLAIN'	=> 'بۆ وێنۆچکە بارکراوەکان.',
	'MIN_AVATAR_SIZE'	=> 'کەمترین دوورییەکانی وێنۆچکە',
	'MIN_AVATAR_SIZE_EXPLAIN'	=> 'پانی x بەرزی بە خاڵ.',
	'ACP_MESSAGE_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت گشت ڕێکخستنە بنەڕەتییەکان دابنێیت بۆ پەیامکردنی تایبەت.',
	'ALLOW_BBCODE_PM'	=> 'ڕێگابدە بە BBCode لە پەیامە تایبەتەکان',
	'ALLOW_FLASH_PM'	=> 'ڕێگابدە بە بەکاربردنی تاگی <code>[FLASH]</code>',
	'ALLOW_FLASH_PM_EXPLAIN'	=> 'تێبینی بکە توانایی بۆ بەکاربردنی فلاش لە پەیامە تایبەتەکان، ئەگەر لێرە چالاککرا، دەشکەوێتەوە سەر دەسەڵاتەکان.',
	'ALLOW_FORWARD_PM'	=> 'بۆناردن چالاکبکە لە پەیامی تایبەت',
	'ALLOW_IMG_PM'	=> 'ڕێگابدە بە بەکاربردنی تاگی <code>[IMG]</code>',
	'ALLOW_MASS_PM'	=> 'ڕێگابدە بە ناردنی پەیامی تایبەت بۆ فرە بەکارهێنەری لەگەڵ فرە گرووپی.',
	'ALLOW_MASS_PM_EXPLAIN'	=> 'ناردن بۆ گرووپ دەتوانێت بکرێت بۆبەر گرووپێک لەناو پەڕەی ڕێکخستنەکانی گرووپەکە.',
	'ALLOW_PRINT_PM'	=> 'ڕێگابدە بە بینینی چاپ لە پەیامکردنی تایبەت',
	'ALLOW_QUOTE_PM'	=> 'ڕێگابدە بە ئاماژەکان لە پەیامە تایبەتەکان',
	'ALLOW_SIG_PM'	=> 'ڕێگابدە بە واژۆ لە پەیامە تایبەتەکان',
	'ALLOW_SMILIES_PM'	=> 'ڕێگابدە بە خەندەکان لە پەیامە تایبەتەکان',
	'BOXES_LIMIT'	=> 'زۆرترین پەیامی تایبەت لە خشتەیەکدا',
	'BOXES_LIMIT_EXPLAIN'	=> 'بەکارهێنەران لەوانەیە هیچی تر وەرنەگرن لەو پەیامانە زیاتر لە هەر خشتەیەکی پەیامە تایبەتەکانیان. ئەو نرخە بۆ 0 دابنێ بۆ ڕێگادان بە بێ-سنووری پەیامەکان.',
	'BOXES_MAX'	=> 'زۆرترین بوخچەی پەیامە تایبەتەکان',
	'BOXES_MAX_EXPLAIN'	=> 'بەهۆی بنەڕەت بەکارهێنەران دەتوانن ئەو بوخچە زۆرانە دروستبکەن بۆ پەیامە تایبەتەکان.',
	'ENABLE_PM_ICONS'	=> 'بەکاربردنی ئایکۆنی بابەت چالاکبکە لە پەیامە تایبەتەکان',
	'FULL_FOLDER_ACTION'	=> 'کردەی بنەڕەتی بوخچەی تەواو',
	'FULL_FOLDER_ACTION_EXPLAIN'	=> 'کردەی بنەڕەت بۆ کردن ئەگەر بوخچەی بەکارهێنەرێک پڕ بوو ،ئەگەر لە هەموو دانرا ئەوا خۆگونجێن نییە. تاکە کلیل بۆ بوخچەی "پەیامە نێردراوەکان" کە کردە بنەڕەتەکە هەمیشە بۆ سڕینەوەی پەیامە کۆنەکانە.',
	'HOLD_NEW_MESSAGES'	=> 'پەیامە نوێیەکان هەڵبگرە',
	'PM_EDIT_TIME'	=> 'سنووردارکردنی کاتی دەستکاریکردن',
	'PM_EDIT_TIME_EXPLAIN'	=> 'سنووردارکردنی کاتەکە بەردەستە بۆ دەستکاری پەیامێکی تایبەت کە هێشتا نەگەیشتووە. دانانی رخەکە بۆ 0 ئەمە ناچالاک دەکات.',
	'PM_MAX_RECIPIENTS'	=> 'زۆرترین ژمارەی وەرگری ڕێگاپێدراو .',
	'PM_MAX_RECIPIENTS_EXPLAIN'	=> 'زۆرترین ژمارەی وەرگری ڕێگاپێدراو لە پەیامێکی تایبەت. ئەگەر 0 نووسرا، ژمارەیەکی بێ-سنوور ڕێگادەدرێ. ئەو ڕێکخستنە دەتوانرێ دابنرێ بۆ هەموو گرووپێک لەناو پەڕەی ڕێکخستنی گرووپەکان.',
	'ACP_POST_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت هەموو ڕێکخستنە بنەڕەتەکان دابنێی بۆ ناردن.',
	'ALLOW_POST_LINKS'	=> 'ڕێگابدە بە بەستەرەکان لە پەیامەکان/پەیامە تایبەتەکان',
	'ALLOW_POST_LINKS_EXPLAIN'	=> 'ئەگەر تاگی <code>[URL]</code> ناچالاککرا ئەوا URL ـــی خۆکارانە/جادوو ناچالاک دەبێت.',
	'ALLOW_POST_FLASH'	=> 'ڕێگادان بە بەکاربردنی تاگی <code>[FLASH]</code> لە پەیامەکان.',
	'ALLOW_POST_FLASH_EXPLAIN'	=> 'ئەگەر تاگی <code>[FLASH]</code> ناچالاککرا لە پەیامەکان. بەپێچەوانەوە سیستەمی کۆنترۆڵی دەسەڵاتەکە کە بەکارهێنەران دەتوانن تاگی <code>[FLASH]</code> بەکاربەرن.',
	'BUMP_INTERVAL'	=> 'ماوەی پێکدادان',
	'BUMP_INTERVAL_EXPLAIN'	=> 'ژمارەی خولەکەکان ،کاتژمێرەکان یان ڕۆژەکان لەنێوان دوا پەیام بۆ بابەتێک لەگەڵ توانایی بۆ پێکدادانی ئەو بابەتە ،دانای نرخی 0 بەتەواوی پێکدادان ناچالاک دەکات.',
	'CHAR_LIMIT'	=> 'زۆرترین تیپ لە پەیامێکدا',
	'CHAR_LIMIT_EXPLAIN'	=> 'ژمارەی تیپە ڕێگاپێدراوەکان لەناو پەیامێک. 0 دابنێ بۆ تیپە بێ سنوورەکان.',
	'DELETE_TIME'					=> 'سنووردارکردنی کاتی سڕینەوە',
	'DELETE_TIME_EXPLAIN'			=> 'سنووردارکردنی کاتەکە بەردەستە بۆ سڕینەوەی پەیامێکی نوێ. دانانی نرخەکە بۆ 0 ئەو ڕەوشتە ناچالاک دەکات.',
	'DISPLAY_LAST_EDITED'	=> 'زانیاری کاتی دوا دەستاری پیشان بدە',
	'DISPLAY_LAST_EDITED_EXPLAIN'	=> 'هەڵبژێرە ئەگەر زانیاری دوا دەستکاری لەلایەن نیشانبدرێت لە پەیامەکان.',
	'EDIT_TIME'	=> 'سنووردارکردنی کاتی دەستکاریکردن',
	'EDIT_TIME_EXPLAIN'	=> 'سنووردارکردنی کاتەکە بەردەستە بۆ دەستکاری پەیامێکی نوێ. دانانی نرخەکە بۆ 0 ئەو ڕەوشتە ناچالاک دەکات.',
	'FLOOD_INTERVAL'	=> 'ماوەی فلوود/شلە',
	'FLOOD_INTERVAL_EXPLAIN'	=> 'ژمارەی ئەو چرکانەی بەکارهێنەرێک پێویستە چاوەڕێ بکات لەنێوان ناردنی پەیامێکی نوێدا. بۆ چالاککردنی بەکارهێنەران بۆ پشتگوێ خستنی ئەوە ،دەسەڵاتیان بگونجێنە.',
	'HOT_THRESHOLD'	=> 'دەرچەی بابەتە گرنگەکان',
	'HOT_THRESHOLD_EXPLAIN'	=> 'دەرچەی پەیامەکان لە بابەتێکدا داواکراوە بۆ دەرخستنی بابەتە گرنگەکە. 0 دابنێ بۆ ناچالاککردنی بابەتە گرنگەکان.',
	'MAX_POLL_OPTIONS'	=> 'زۆرترین ژمارەی هەڵبژاردنەکانی ڕاپرسی',
	'MAX_POST_FONT_SIZE'	=> 'گەورەترین قەبارەی فۆنت بۆ هەر پەیامێک',
	'MAX_POST_FONT_SIZE_EXPLAIN'	=> 'زۆرترین قەبارەی فۆنتی ڕێپێدراو لە پەیامەکاندا. 0 بنووسە بۆ بێ سنوور.',
	'MAX_POST_IMG_HEIGHT'	=> 'زۆرترین بەرزی وێنە بۆ هەر پەیامێک',
	'MAX_POST_IMG_HEIGHT_EXPLAIN'	=> 'زۆرترین بەرزی وێنە/فلاش لە پەیامەکاند. 0 بنووسە بۆ بێ سنوور.',
	'MAX_POST_IMG_WIDTH'	=> 'زۆرترین پانی وێنە بۆ هەر پەیامێک',
	'MAX_POST_IMG_WIDTH_EXPLAIN'	=> 'زۆرترین پانی وێنە/فلاش لە پەیامەکاند. 0 بنووسە بۆ بێ سنوور.',
	'MAX_POST_URLS'	=> 'زۆرترین بەستەر بۆ هەر پەیامێک',
	'MAX_POST_URLS_EXPLAIN'	=> 'زۆرترین ژمارەی بەستەر لە پەیامێکدا. 0 بنووسە بۆ بێ سنوور.',
	'MIN_CHAR_LIMIT'				=> 'کەمترین نووسە بۆ هەر پەیامێک',
	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'کەمترین ژمارەی نووسە کە بەکارهێنەر پێویستە بینووسێت لە پەیام یان پەیامێکی تایبەتیدا. نرخی 1 کەمترینە بۆ ئەو ڕێکخستنە.',
	'POSTING'	=> 'پەیام ناردن',
	'POSTS_PER_PAGE'	=> 'پەیامەکان بۆ هەر پەڕەیەک',
	'QUOTE_DEPTH_LIMIT'				=> 'زۆرترین فراوانی بۆ ئاماژەکان.',
	'QUOTE_DEPTH_LIMIT_EXPLAIN'		=> 'زۆرترین فراوانی بۆ ئاماژە لە پۆستێکدا. 0 دابنێ بۆ فراوانی بێ سنوور.',
	'SMILIES_LIMIT'	=> 'زۆرترین ژمارەی خەندە بۆ هەر پەیامێک',
	'SMILIES_LIMIT_EXPLAIN'	=> 'زۆرترین ژمارەی خەندە لە پەیامدا. 0 بنووسە بۆ بێ سنوور',
	'SMILIES_PER_PAGE'				=> 'خەندەکان بۆ هەر پەڕەیەک',
	'TOPICS_PER_PAGE'	=> 'بابەتەکان بۆ هەر پەڕەیەک',
	'ACP_SIGNATURE_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت هەموو ڕێکخستنە بنەڕەتەکان دابنێی بۆ واژۆکان.',
	'MAX_SIG_FONT_SIZE'	=> 'زۆرترین قەبارەی فۆنتی واژۆ',
	'MAX_SIG_FONT_SIZE_EXPLAIN'	=> 'زۆرترین قەبارەی فۆنت ڕێگادراوە لە واژۆی بەکارهێنەران. 0 دابنێ بۆ قەبارەی بێ سنوور.',
	'MAX_SIG_IMG_HEIGHT'	=> 'زۆرترین بەرزی وێنەی واژۆ',
	'MAX_SIG_IMG_HEIGHT_EXPLAIN'	=> 'زۆرترین بەرزی پەڕگەیەکی وێنە/فلاش لە واژۆی بەکارهێنەران. 0 دابنێ بۆ بەرزی بێ سنوور.',
	'MAX_SIG_IMG_WIDTH'	=> 'زۆرترین فراوانی وێنە واژۆ',
	'MAX_SIG_IMG_WIDTH_EXPLAIN'	=> 'زۆرترین فراوانی پەڕگەیەکی وێنە/فلاش لە واژۆی بەکارهێنەران. 0 دابنێ بۆ فراوانی بێ سنوور.',
	'MAX_SIG_LENGTH'	=> 'زۆرترین درێژی واژۆ',
	'MAX_SIG_LENGTH_EXPLAIN'	=> 'زۆرترین ژمارەی تیپەکان لە واژۆی بەکارهێنەران.',
	'MAX_SIG_SMILIES'	=> 'زۆرترین خەندە لە واژۆیەکدا',
	'MAX_SIG_SMILIES_EXPLAIN'	=> 'زۆرترین خەندە ڕێگاپێدراوە لە واژۆی بەکارهێنەران. 0 دابنێ بۆ خەندەی بێ سنوور.',
	'MAX_SIG_URLS'	=> 'زۆرترین بەستەری واژۆکان',
	'MAX_SIG_URLS_EXPLAIN'	=> 'زۆرترین ژمارەی بەستەرەکان لە واژۆی بەکارهێنەران. 0 دابنێ بۆ بەستەری بێ سنوور.',
	'ACP_REGISTER_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت تۆماربوون و پرۆفایل پێناسە بکەیت لەگەڵ ڕێکخستنە پەیوەندیدارەکان.',
	'ACC_ACTIVATION'	=> 'چالاککردنی هەژمار',
	'ACC_ACTIVATION_EXPLAIN'	=> 'ئەوە دەست گەیشتنی بەکارهێنەر بۆ مەکە دیاری دەکات. دەشتوانی بەتەواوی تۆماربوونی نوێ ناچالاک بکەیت ،"ئیمەیڵی فراوانی-مەکۆ" پێویستە پێویستە چالاک کرابێت بۆ بەکارهێنانی چالاککردنی بەکارهێنەر یان بەڕێوەبەر.',
	'NEW_MEMBER_POST_LIMIT'			=> 'سنووری پەیامی ئەندامی نوێ',
	'NEW_MEMBER_POST_LIMIT_EXPLAIN'	=> 'ئەندامە نوێیەکان لەناو گرووپی <em>ئەندامە تۆماربووەکان</em> ــن تاکو دەگەنە ئەو ژمارەی پەیامانە. دەتوانی ئەو گرووپە بەکاربهێنی بۆ هێشتنەوەیان لە بەکاربردنی سیستەمی پەیامی تایبەتی یان پێداچوونەوە بۆ پەیامەکانیان. <strong>نرخێکی 0 ئەو تایبەتمەندییە ناچالاک دەکات</strong>.',
	'NEW_MEMBER_GROUP_DEFAULT'		=> 'گرووپی ئەندامە تۆماربووەکان بۆ بنەڕەت دابنێ',
	'NEW_MEMBER_GROUP_DEFAULT_EXPLAIN'	=> 'ئەگەر بۆ بەڵێ دانرا و سنووری پەیامی ئەندامێکی نوێ دیاریکراوە ،ئەندامە تۆماربووەکان تەنها دانانرێن بۆناو گرووپی <em>ئەندامە تۆماربووەکان</em> ،بەڵکو ئەو گرووپە دەشبێتە بنەڕەتەکەیان. ئەمە لەوانەیە بەدەست بێت ئەگەر تۆ دەتەوێ پلەی گرووپێکی بنەڕەت پێک بهێنێت لەگەڵ/یان مانەوەی وێنۆچکەی بەکارهێنەر.',
	'ACC_ADMIN'	=> 'لەلایەن بەڕێوەبەر',
	'ACC_DISABLE'	=> 'ناچالاککردنی تۆماربوون',
	'ACC_NONE'	=> 'بەبێ چالاکبوون (دەسەڵاتی ڕاستەوخۆ)',
	'ACC_USER'	=> 'لەلایەن بەکارهێنەر (دڵنیاکردنەوە بە ئیمەیڵ)د',
	'ALLOW_EMAIL_REUSE'	=> 'ڕێ دان بە بەکارهێنانەوەی ئیمەیل',
	'ALLOW_EMAIL_REUSE_EXPLAIN'	=> 'بەکارهێنەرە جیاوازەکان دەتوانن تۆمارببن لەگەڵ هەمان پۆستی ئەلیکترۆنی.',
	'COPPA'	=> 'COPPA',
	'COPPA_FAX'	=> 'ژمارەی فاکسی COPPA',
	'COPPA_MAIL'	=> 'ناونیشانی ئیمەیڵی COPPA',
	'COPPA_MAIL_EXPLAIN'	=> 'ئەوە ناونیشانی ئیمەیڵە کە کەسوکاران فۆرمی تۆماربوونی COPPA دەنێرن.',
	'ENABLE_COPPA'	=> 'COPPA چالاکبکە',
	'ENABLE_COPPA_EXPLAIN'	=> 'ئەوە بەکارهێنەرانی داواکردووە کاتێ ئەوان 13 ساڵ یان زیاتر بۆ گونجاندن لەگەڵ U.S. COPPA. ئەگەر ئەوە ناچالاککراوە ،گرووپی دیاریکراوی COPPA هیچی تر نیشان نادرێت.', 
	'MAX_CHARS'	=> 'زۆرترین',
	'MIN_CHARS'	=> 'کەمترین',
	'NO_AUTH_PLUGIN'	=> 'هیچ پێوەکراوێکی خۆگونجێن نەدۆزرایەوە.',
	'PASSWORD_LENGTH'	=> 'درێژی تێپەڕەوشە',
	'PASSWORD_LENGTH_EXPLAIN'	=> 'کەمترین و زۆرترین ژمارەی تیپەکان لە تێپەڕەوشەکان.',
	'REG_LIMIT'	=> 'هەوڵەکانی خۆتۆمارکردن',
	'REG_LIMIT_EXPLAIN'			=> 'ژمارەی هەوڵەکان کە بەکارهێنەرێک دەتوانێ بیکات لە شیکارکردنی دژە-سپام پێش ئەوەی دابخرێ لە دانیشتنەکە.',
	'USERNAME_ALPHA_ONLY'	=> 'تەنها نووسە و ژمارە',
	'USERNAME_ALPHA_SPACERS'	=> 'پیت، ژمارە و بۆشایی',
	'USERNAME_ASCII'	=> 'ASCII (یونیکۆدی جیهانی نا)',
	'USERNAME_LETTER_NUM'	=> 'هەر پیت یان ژمارەیەک',
	'USERNAME_LETTER_NUM_SPACERS'	=> 'هەر پیت، ژمارە یان بۆشاییەک',
	'USERNAME_CHARS'	=> 'نووسەکانی تێپەڕەوشە سنووردار بکە',
	'USERNAME_CHARS_ANY'	=> 'هەر نووسەیەک',
	'USERNAME_CHARS_EXPLAIN'	=> 'هێشتنەوەی ئەو جۆرانەی تیپەکان کە لەوانەیە بەکارببرێن لە تێپەڕەوشەکان: space, -, +, _, [ لەگەڵ ].',
	'USERNAME_LENGTH'	=> 'درێژی ناوی بەکارهێنەر',
	'USERNAME_LENGTH_EXPLAIN'	=> 'زۆرترین و کەمترین ژمارەی نووسەکان لە ناوی بەکارهێنەردا.',
	'ACP_FEED_MANAGEMENT'				=> 'ڕێکخستی گشتی کۆپەڕەکانی feeds',
	'ACP_FEED_MANAGEMENT_EXPLAIN'		=> 'ئەو یەکەیە وا لە هەمەجۆری ATOM feeds دەکات بەردەست بێت، پێکهێنانی هەر BBCode ــێک لە پەیامەکان بۆ خوێندراو کردنیان لە feed ــە دەرەکییەکان.',
	'ACP_FEED_GENERAL'					=> 'ڕێکخستنە گشتییەکانی feed',
	'ACP_FEED_POST_BASED'				=> 'ڕێکخستنەکانی پەیام-بنچینەکراوی feed',
	'ACP_FEED_TOPIC_BASED'				=> 'ڕێکخستنەکانی بابەت-بنچینەکراوی feed',
	'ACP_FEED_SETTINGS_OTHER'			=> 'feed ــەکانی تر و ڕێکخستنەکان',
	'ACP_FEED_ENABLE'					=> 'feeds چالاکبکە',
	'ACP_FEED_ENABLE_EXPLAIN'			=> 'بەکاربکە یان بێ ATOM feeds بۆ تەواوی مەکۆکە.<br /> ناچالاککردنی ئەو کلیلانە هەموو feed ــەکان دەکوژێنێتەوە، بێ-گرنگیدان بە ڕێکخستنەکانی خوارەوە کە چۆن دانرابن.',
	'ACP_FEED_LIMIT'					=> 'ژمارەی شتەکان',
	'ACP_FEED_LIMIT_EXPLAIN'			=> 'زۆرترین ژمارەی شتەکانی feed بۆ نیشاندان.',
	'ACP_FEED_OVERALL'					=> 'feed ــی فراوانی-مەکۆ چالاکبکە',
	'ACP_FEED_OVERALL_EXPLAIN'			=> 'پەیامە نوێیەکانی فراوانی-مەکۆ.',
	'ACP_FEED_FORUM'					=> 'feed ــی بۆهەر-مەکۆیەک چالاکبکە',
	'ACP_FEED_FORUM_EXPLAIN'			=> 'پەیامە نوێیەکانی تاکە مەکۆ لەگەڵ ژێرمەکۆکان.',
	'ACP_FEED_TOPIC'					=> 'feed ــی بۆهەر-بابەتێک چالاکبکە',
	'ACP_FEED_TOPIC_EXPLAIN'			=> 'پەیامە نوێیەکانی تاکە بابەتەکان.',
	'ACP_FEED_TOPICS_NEW'				=> 'feed ــی بابەتە نوێیەکان چالاکبکە',
	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'feed ـــی"بابەتە نوێیەکان" چالاکبکە، کە دوایین بابەتە دروستکراوەکان نیشاندەدات لەناویاندا یەکەم پەیام.',
	'ACP_FEED_TOPICS_ACTIVE'			=> 'feed ــی بابەتە چالاکەکان چالاکبکە',
	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'feed ــی "بابەتە چالاکەکان" چالاکبکە ،کە دوایین بابەتە چالاکەکان نیشاندەدات لەناویاندا دوا پەیامیش.',
	'ACP_FEED_NEWS'						=> 'News feed',
	'ACP_FEED_NEWS_EXPLAIN'				=> 'یەکەم پەیام لەو مەکۆیانە پاڵبدە. هیچ مەکۆیەک بۆ نیشاندانی news feed هەڵبژێرە.<br /> فرە مەکۆکان هەڵبژێرە بە داگرتنی <samp>CTRL</samp> لەگەڵ کرتەکردن.',
	'ACP_FEED_OVERALL_FORUMS'			=> 'feed ــی مەکۆکان چالاکبکە',
	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'feed ــی "هەموو مەکۆکان" چالاکبکە ،کە لیستێک لە مەکۆکان نیشاندەدات.',
	'ACP_FEED_HTTP_AUTH'				=> 'ڕێگابدە بە پەسەندکردنەوەی HTTP',
	'ACP_FEED_HTTP_AUTH_EXPLAIN'		=> 'چالاککردنی پەسەندکردنەوەی HTTP, کە ڕێگا بە بەکارهێنەران دەدات بۆ وەرگرتنی ناوەڕۆک کە شاراوەیە بۆ گۆڕانکارییەکانی پەڕگەی .htaccess .ڕێبەرەکان دەتوانرێ ببینرێن لەو پەڕگەیە.',
	'ACP_FEED_ITEM_STATISTICS'			=> 'ئاماری شتەکان',
	'ACP_FEED_ITEM_STATISTICS_EXPLAIN'	=> 'نیشاندانی ئاماری زانیاریکراوی بەجێ لەژێر feed ــی شتەکان <br /> (بۆ نموونە. نێردراوە لەلایەن، کات و بەروار ،وەڵامەکان ،بینینەکان)',
	'ACP_FEED_EXCLUDE_ID'				=> 'خستنەنێوی ئەو مەکۆیانە',
	'ACP_FEED_EXCLUDE_ID_EXPLAIN'		=> 'ناوەڕۆک لەوانە <strong>ناخرێتە ناو feed ــەكان</strong>. هیچ مەکۆیەک هەڵبژێرە بۆ پاڵنانی داتا لە هەموو مەکۆکان.<br />فرە مەکۆکان هەڵبژێرە/هەڵمەبژێرە بە داگرتنی <samp>CTRL</samp> لەگەڵ کرتەکردن.',
'ACP_VC_SETTINGS_EXPLAIN'				=> 'لێرە دەتوانیت پێوەکراوەکان دەستنیشان و دیمەن بکەیت، کە دیزاینکراون بۆ خۆکارکراون لە ژێرئامانجەکان لەلایەن spambots ،ئەو پێوەکراوانە بەرکاری کاردەکەن بەهۆی پێشبڕکێی بەکارهێنەرەکە لەگەڵ <em>CAPTCHA</em>. تاقیکردنەوەیەک کە دیزاینکراوە بۆ دژوارکردن بۆ کۆمپیوتەرەکان بۆ شیکار.',
	'AVAILABLE_CAPTCHAS'					=> 'پێوەکراوە بەردەستەکان',
	'CAPTCHA_UNAVAILABLE'					=> 'پێوەکراوەکە ناتوانرێ دەستنیشان بکرێت وەکو ئەوەی داواکراوە لەگەڵی نایەنەوە.',
	'CAPTCHA_GD'							=> 'وێنەی GD',
	'CAPTCHA_GD_3D'							=> 'وێنەی 3D GD',
	'CAPTCHA_GD_FOREGROUND_NOISE'			=> 'ئاماژەی ژێرپەردە',
	'CAPTCHA_GD_EXPLAIN'					=> 'سوودی GD بۆ زیاتر پەرەسەندووکردنی وێنەی دژە-سپام.',
	'CAPTCHA_GD_FOREGROUND_NOISE_EXPLAIN'	=> 'ئاماژەی ژێرپەردە بەکارببە بۆ والێکردنی وێنەکە دژوار بێت بۆ خوێندنەوە.',
	'CAPTCHA_GD_X_GRID'						=> 'ئاماژەی ڕووپەردەی x-axis',
	'CAPTCHA_GD_X_GRID_EXPLAIN'				=> 'ڕێکخستنە نزمترەکان بەکارببە بۆ والێکردنی وێەکە دژوار بێت بۆ خوێندنەوە. نرخی 0 x-axis ناچالاکدەکات.',
	'CAPTCHA_GD_Y_GRID'						=> 'ئاماژەی ڕووپەرەی y-axis',
	'CAPTCHA_GD_Y_GRID_EXPLAIN'				=> 'ڕێکخستنە نزمترەکان بەکارببە بۆ والێکردنی وێەکە دژوار بێت بۆ خوێندنەوە. نرخی 0 y-axis ناچالاکدەکات.',
	'CAPTCHA_GD_WAVE'						=> 'شێواندنی شەپۆل',
	'CAPTCHA_GD_WAVE_EXPLAIN'				=> 'ئەمە شێواندنێکی شەپۆلی جێبەجێ دەکات بۆ وێنەکە.',
	'CAPTCHA_GD_3D_NOISE'					=> 'شتەکانی ئاماژەی-3D زیادبکە',
	'CAPTCHA_GD_3D_NOISE_EXPLAIN'			=> 'ئەمە شتە زیادەکان زیاد دەکات بۆ وێنەکە ،لەسەر پیتەکان.',
	'CAPTCHA_GD_FONTS'						=> 'فۆنتە جیاوازییەکان بەکارببە',
	'CAPTCHA_GD_FONTS_EXPLAIN'				=> 'ئەو ڕێکخستنانە پیتە جیاوازەکان کۆنترۆڵ دەکەن، دەتوانی تەنها شێوە بنەڕەتەکان بەکارببەی یان پیتە لەجێیەکان بەرهەمدێت، زیادکردنی پیتەکانی بارنزمتر دەتوانرێت بکرێت.',
	'CAPTCHA_FONT_DEFAULT'					=> 'بنەڕەت',
	'CAPTCHA_FONT_NEW'						=> 'شێوە نوێیەکان',
	'CAPTCHA_FONT_LOWER'					=> 'هەروەها بارنزمتر بەکارببە',
	'CAPTCHA_NO_GD'							=> 'وێنەی سادە',
	'CAPTCHA_PREVIEW_MSG'					=> 'گۆڕانکارییەکانت پاشەکەوت نەکراون، ئەمە تەنها پێشبینینە.',
	'CAPTCHA_PREVIEW_EXPLAIN'				=> 'پێوەکراوەکە وەکو ئەوەی دەیەوێ ئەو دەستنیشانکراوە بەکارببات.',
	'CAPTCHA_SELECT'						=> 'پێوەکراوەکە دامەزراوەکان',
	'CAPTCHA_SELECT_EXPLAIN'				=> 'خوارفڕێدان پێوەکراوەکان دەگرێت کە ڕێزبەندی کراون لەلایەن مەکۆکە. تەواوەتی بەردەست نین ئێستاکە و لەوانەشە دیمەنکردنی پێویست بێت بۆ بەکارهێنان.',
	'CAPTCHA_CONFIGURE'						=> 'دیمەنکردنی پێوەکراوەکان',
	'CAPTCHA_CONFIGURE_EXPLAIN'				=> 'ڕێکخستنەکان بگۆڕە بۆ پێوەکراوە دەستنیشان کراوەکە.',
	'CONFIGURE'								=> 'دیمەنکردن',
	'CAPTCHA_NO_OPTIONS'					=> 'ئەو پێوەکراوە هەڵبژاردنەکانی دیمەنکردنی نییە.',
	'VISUAL_CONFIRM_POST'					=> 'ژمارە دڵنیایی چالاکبکە بۆ ناردنەکانی میوان',
	'VISUAL_CONFIRM_POST_EXPLAIN'			=> 'داوادەکرێ بەکارهێنەری میوان بۆ دەرچوونی دژە-سپام بۆ یارمەتی لە پەیامکردنی خۆکارکراو.',
	'VISUAL_CONFIRM_REG'					=> 'ژمارە دڵنیایی سپام چالاکبکە بۆ تۆماربوون',
	'VISUAL_CONFIRM_REG_EXPLAIN'			=> 'داوادەکرێ بەکارهێنەرە نوێیەکان لە ئەزموونی دژە-سپام دەربچن بۆ یارمەتیدان لە دوورخستنەوەی تۆماربوونە خۆکرارکراوەکان.',
	'VISUAL_CONFIRM_REFRESH'				=> 'ڕێگابدە بە بەکارهێنەران بۆ تازەکردنەوەی ئەزموونی دژە-سپام',
	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'ڕێگابدە بە بەکارهێنەران بۆ داواکردنی ئەزموونێکی دژە-سپامی نوێ ئەگەر نەیانتوانی ئەزموونی ئامادە شیکاربکەن لەکاتی تۆماربوون. هەندێ لە پێوەکراوان لەوانە نییە پاڵپشتی ئەو هەڵبژاردنە بکەن.',
	'ACP_COOKIE_SETTINGS_EXPLAIN'	=> 'ئەو وردەکارییانە داتای بەکارهاتوو بۆ ناردنی شەکرۆکەکان بۆ وێبگەڕی بەکارهێنەرەکانت پێناسە دەکات. لە زۆربەی بارەکان نرخی بنەڕەت بۆ ڕێکخستنەکانی شەکرۆکە دەبێ گونجاو بێت. ئەگەر تۆ پێویستت نییە هەر کردەیەک بگۆڕیت و لەگەڵیدا بەکارببەی لەگەڵ گرنگیدان. رێکخستنە نادروستەکان دەتوانن چوونەژوورەوەی بەکارهێنەران بەدوور بگرن.',
	'COOKIE_DOMAIN'	=> 'دۆمەینی شەکرۆکە',
	'COOKIE_NAME'	=> 'ناوی شەکرۆکە',
	'COOKIE_PATH'	=> 'ڕێڕەوی شەکرۆکە',
	'COOKIE_SECURE'	=> 'ئاسایشی شەکرۆکە',
	'COOKIE_SECURE_EXPLAIN'	=> 'ئەگەر ڕاژەکەت لەڕێگای SSL دەڕوات .ئەوە دابنێ بۆ چالاککردنی و بەجێ هێشتنی وەکو ناچالاک. بوونی ئەم چالاککراوە و نەڕۆشتن لەسەری لەرێگای SSL ،ئەنجامی دەبێت لە هەڵەکانی ڕاژەکەت لەکاتی گەڕاندنەوە.',
	'ONLINE_LENGTH'	=> 'بینینی مەوداری سەرهێڵی کات',
	'ONLINE_LENGTH_EXPLAIN'	=> 'ژمارەی خولەکەکان لەدوای ئەوەی ناچالاکە بەکارهێنەران دەرناکەون لە لیستی "ئەندامە تۆماربووەکانی سەرهێڵ" .بەرزترینی ئەو نرخە کرداری مەزنترە داواکراوە بۆ دەرخستنی لیستەکە.',
	'SESSION_LENGTH'	=> 'درێژی وەرز',
	'SESSION_LENGTH_EXPLAIN'	=> 'دانیشتنەکان بەسەردەچن لەدوای ئەو کاتە، لە چرکەکان.',
	'ACP_LOAD_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت کۆمەڵێک نەخشەی مەکۆ چالاک و ناچالاک بکەیت بۆ گەڕاندنەوەی مەودای کردارکردنی داواکراو. لەسەر زۆربەی ڕاژەکان هیچ پێویست ناکات بۆ ناچالاککردنی نەخشەکان. هەرچۆنێکە لەسەر کۆمەڵێ سیستەمەکان یان بەرهەمهێنانی خانەخوێی بەشدارکراو لەوانەیە ناچالاکردنی گونجاندنی زیاتر بدات بە تۆ. هەروەها دەتوانی سنوورەکان دیاریبکەی بۆ بارکردنی سیستەم و چالاککردنی دانیشتنەکان لەدوای ئەوەی کە مەکۆکە دەڕواتە دەرهێڵ.',
	'CUSTOM_PROFILE_FIELDS'	=> 'خانە هەڵبژاردانەکانی پرۆفایل',
	'LIMIT_LOAD'	=> 'بارکردنی سیستەم سنوورداربکە',
	'LIMIT_LOAD_EXPLAIN'	=> 'ئەگەر 1-خولەکی سیستەمەکە باردەبێ لەسەروو ئەو نرخە مەکۆکە خۆکارانە دەچێتە دەرهێڵ. نرخێکی 1.0 یەکسانە بە ~100% لەسەر یەک وەگەڕخەر. ئەو نەخشە تەنهایە لەسەر ڕاژەکانی بنچینەکراوی UNIX و کە ئەو زانیارییە بەردەستە. نرخەکە لێرە خۆی بۆ 0 ئەگەر phpBB نەیتوانی سنووری بارکردنی بهێنێت.',
	'LIMIT_SESSIONS'	=> 'سنووردارکردنی دانیشتنەکان',
	'LIMIT_SESSIONS_EXPLAIN'	=> 'ئەگەر ژمارەی دانیشتنەکان لەسەروو ئەو نرخەیە لەناو یەک خولەکدا ،مەکۆکە دەچێتە دەرهێڵ. 0 دابنێ بۆ دانیشتنە بێ-سنوورەکان.',
	'LOAD_CPF_MEMBERLIST'	=> 'ڕێگابدە بە شێوازەکان بۆ نیشاندانی پرۆفایلی ئارەزوومەندانە لە لیستی ئەندامان',
	'LOAD_CPF_VIEWPROFILE'	=> 'نیشاندانی خانەکانی پرۆفایلی ئارەزوومەندانە لە پرۆفایلی بەکارهێنەران',
	'LOAD_CPF_VIEWTOPIC'	=> 'نیشاندانی خانەکانی پرۆفایلی ئارەزوومەندانە لەسەر پەڕەی بابەتەکان',
	'LOAD_USER_ACTIVITY'	=> 'چالاکییەکانی بەکارهێنەر نیشانبدە',
	'LOAD_USER_ACTIVITY_EXPLAIN'	=> 'نیشاندانی مەکۆ/بابەتی چالاک لە پرۆفایلی بەکارهێنەر و کۆنترۆڵ پانێڵی بەکارهێنەر. ئامۆژگاریکراوە بۆ ناچالاککردنی ئەوە لەسەر مەکۆکان لەگەڵ زیاتر لە یەک ملیۆن پەیام.',
	'RECOMPILE_STYLES'	=> 'گونجاندنەوەی ئاوێتەکانی شێواز',
	'RECOMPILE_STYLES_EXPLAIN'	=> 'بۆ ئاوێتەکانی شێوازی نوێکراوە بپشکنە لەسەر پەڕگەسیستە، و گوانجاندنەوە.',
	'YES_ANON_READ_MARKING'	=> 'دەستنیشانکردنی بابەت بۆ میوانان چالاکبکە',
	'YES_ANON_READ_MARKING_EXPLAIN'	=> 'کۆگاکردنی زانیاری باری خوێندنەوە/نەخوێندنەوە بۆ میوانان. ئەگەر ناچالاککرا ،پەیامەکان هەمیشە وەکو خوێندراو دەستنیشان دەکرێن بۆ میوانان.',
	'YES_BIRTHDAYS'	=> 'لیستی ڕۆژی لەدایکبوون چالاکبکە',
	'YES_BIRTHDAYS_EXPLAIN'	=> 'ئەگەر لیستی ڕۆژی لەدایکبوون ناچالاککرا هیچی تر نیشان نادرێت. بۆ ڕێدانی ئەمە و بوونی کاریگەری بۆ تایبەتمەندی ڕۆژی لەدایکبوون پێویستە ئەویش چالاکبکرێت.',
	'YES_JUMPBOX'	=> 'نیشاندانی بازەخشتە چالاکبکە',
	'YES_MODERATORS'	=> 'نیشاندانی چاودێران چالاکبکە',
	'YES_ONLINE'	=> 'لیستی بەکارهێنەرانی سەرهێڵ چالاکبکە',
	'YES_ONLINE_EXPLAIN'	=> 'زانیاری بەکارهێنەری سەرهێڵ نیشانبدە لەسەر پێڕست ،پەڕەی مەکۆ و بابەتەکان.',
	'YES_ONLINE_GUESTS'	=> 'لیستی میوانانی سەرهێڵ چالاکبکە لە بینینی سەرهێڵ',
	'YES_ONLINE_GUESTS_EXPLAIN'	=> 'زانیاری بەکارهێنەری میوان نیشانبدە لە بینینی سەرهێڵ.',
	'YES_ONLINE_TRACK'	=> 'نیشاندانی زانیاری بەکارهێنەری سەرهێڵ/دەرهێڵ چالاکبکە',
	'YES_ONLINE_TRACK_EXPLAIN'	=> 'زانیاری سەرهێڵ بۆ بەکارهێنەر نیشانبدە لە پرۆفایلەکان و پەڕەی بابەتەکان.',
	'YES_POST_MARKING'	=> 'بابەتە خاڵکراوەکان چالاکبکە',
	'YES_POST_MARKING_EXPLAIN'	=> 'بیخەپاڵ لەکوێ بەکارهێنەر پەیامی ناردووە بۆ بابەتێک.',
	'YES_READ_MARKING'	=> 'نیشانەکردنی بابەتی لا-ڕاژە چالاکبکە',
	'YES_READ_MARKING_EXPLAIN'	=> 'کۆگاکردنی زانیاری باری خوێندنەوە/نەخوێندنەوە لە بنکەدراوەکە لەباتی شەکرۆکەیەک.',
	'YES_UNREAD_SEARCH'				=> 'گەڕان بۆ پەیامە نەخوێندراوەکان چالاکبکە',
	'ACP_AUTH_SETTINGS_EXPLAIN'	=> 'phpBB پاڵپشتی دەکات لە پێوە-کراوە پەسەندکراوەکان. یان یەکەکان. ئەمانە ڕێگات دەدەن بۆ دیاریکردنی چەند بەکارهێنەر زانیاری زێدەکراون کەواتە تەنها خانەکان پڕبکەوە ئەگەر ئەوان پەیوەندیداربوون بە ڕێگای دەست نیشانکراو.',
	'AUTH_METHOD'	=> 'ڕێگایەکی پەسەندکراو هەڵبژێرە',
	'APACHE_SETUP_BEFORE_USE'	=> 'پێویستە تۆ پەسەندکردنی ئەپاچی دابمەزرێنی پێش ئەوەی phpBB بکەیتە ئەو ڕێگا پەسەندکراوە. لەیادت بێت ناوی بەکارهێنەرەکە کە بەکاری دەبەی بۆ پەسەندکردنی ئەپاچی دەبێ هەمان ڕێگا بێت وەکو ناوی بەکارهێنەری phpBB ــەکەت. پەسەندکردنی ئەپاچی تەنها دەتوانرێ بەکارببرێت لەگەڵ mod_php لەگەڵ safe_mode چالاکرابێت.',
	'LDAP_DN'	=> 'LDAP بنکەی <var>dn</var>',
	'LDAP_DN_EXPLAIN'	=> 'ئەوە ناوی بێ-هەژمارە، شوێنکردنی زانیاری بەکارهێنەر ،نموونە <samp>o=Kompanyay min,c=US</samp>.',
	'LDAP_EMAIL'	=> 'ئیمەیڵی ڕەسەنێتی LDAP',
	'LDAP_EMAIL_EXPLAIN'	=> 'ئەوە دابنێ بۆ ناوی بەکارهێنەرەکەت ئیمەیڵی ڕەسەنێتی (ئەگەر هەیە) داوادەکرێ کە خۆکارانە ناونیشانی ئیمەیڵ دابنرێ بۆ بەکارهێنەرە نوێیەکان. جێ-هێشتنی ئەمە بە بەتاڵی ئەنجامی دەبێت بۆ ناونیشانی ئیمەیڵ بۆ بەکارهێنەران کە چوونە ژوورەوە بۆ یەکەم جار.',
	'LDAP_INCORRECT_USER_PASSWORD'	=> 'بەرگکردن بۆ ڕاژەی LDAP سەرنەکەوت لەگەڵ بەکارهێنەر/تێپەڕەوشەی دیاریکراو.',
	'LDAP_NO_EMAIL'	=> 'ئیمەیڵی دیاریکراو بوونی نییە.',
	'LDAP_NO_IDENTITY'	=> 'نەتوانرا پێناسی چوونەژوورەوە بدۆزرێتەوە بۆ %s .',
	'LDAP_PASSWORD'	=> 'تێپەڕەوشەی LDAP',
	'LDAP_PASSWORD_EXPLAIN'			=> 'بە بەتاڵی جێی بهێڵە بۆ بەکاربردنی بەرگکردنی نەناسراو. یانیش لە تێپەڕەوشەکە پڕبکەوە بۆ بەکارهێنەری سەروو. داواکراوە بۆ ڕاژەکانی شوێنگە/پێڕستی چالاک.<br /><em><strong>ئاگاداری:</strong> ،ئەو تێپەڕەوشەیە کۆگادەکرێت وەکو دەقی نەخشە لە بنکەدراوەکە ،بۆ هەمووان دەردەکەوێ ئەوەی کە دەتوانێ بگات بە بنکەدراوەکەت یان ئەوەی کە دەتوانێ پەڕەی دیمەنکردن ببینێ.</em>',
	'LDAP_PORT'	=> 'دەرگای ڕاژەی LDAP',
	'LDAP_PORT_EXPLAIN'	=> 'هەڵبژاردانە تۆ دەتوانێ دەرگایەک دیاریبکەی کە دەتوانرێ بەکارببرێن بۆ پەیوەندی گرتن بۆ ڕاژەی LDAP لەباتی دەرگای بنەڕەت کە بریتییە لە 389.',
	'LDAP_SERVER'	=> 'ناوی ڕاژەی LDAP',
	'LDAP_SERVER_EXPLAIN'	=> 'ئەگەر LDAP بەکاردەبەیت ئەوە ناوی خانەخوێیەکەیە یان ناونیشانی IP ــی ڕاژەی LDAP .لەجیاتیانە تۆ دەتوانی URL ــێک دیاریبکەی وەکو ldap://hostname:port/',
	'LDAP_UID'	=> 'LDAP <var>uid</var>',
	'LDAP_UID_EXPLAIN'	=> 'ئەوە کلیلەکەیە لەژێر بۆ گەڕان بۆ پێناسێکی دراوی چوونەژوورەوە. نموونە <var>uid</var>, <var>sn</var>, ..هتد',
	'LDAP_USER'	=> 'بەکارهێنەری LDAP <var>dn</var>',
	'LDAP_USER_EXPLAIN'	=> 'بە بەتاڵی جێی بهێڵە بۆ بەرگکردنی بەکارهێنانی نەناسراو. ئەگەر پڕکرایەوە لە بەکارهێنانەکانی phpBB ناوە دیاریکراوەکە لەسەر هەوڵەکانی چوونەژوورەوە بۆ دۆزینەوەی بەکارهێنەرە دروستەکە ،نموونە <samp>uid=Username,ou=MyUnit,o=MyCompany,c=US</samp> ،داواکراوە بۆ ڕاژەکانی پێڕستی چالاک.',
	'LDAP_USER_FILTER'	=> 'فلتەری بەکارهێنەری LDAP',
	'LDAP_USER_FILTER_EXPLAIN'	=> 'هەڵبژاردانە دەتوانی شتە گەڕاوەکان سنووردار بکەی لەگەڵ فلتەرە زۆرکراوەکان. بۆ نموونە <samp>objectClass=posixGroup</samp> ئەنجامی دەبێت لە بەکاربردنەکەی <samp>(&amp;(uid=$username)(objectClass=posixGroup))</samp>',
	'ACP_SERVER_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت ڕاژە و ناوە دۆمێین پێناسە بکەیت بەپێی ڕێکخستنەکان. تکایە دڵنیاببە داتای نووسراو تۆمارکراوە ،هەڵەکان ئەنجامی دەبێت لە ئیمەیڵی لەخۆگرتوو بۆ زانیاری نادروست. لەکاتی نووسینی ناوە دۆمێین لەیادت بێت http:// لەخۆ دەگرێت یان مەرجەکانی تری پرۆتۆکۆل. تەنها گۆڕاوی ژمارەی دەرگاکە ئەگەر تۆ دەزانی ڕاژەکەت نرخێکی جیاواز بەکاردەبات ،دەرگای 80 دروستە لە زۆربەی بارەکان.',
	'ENABLE_GZIP'	=> 'پەستاندنی GZip چالاکبکە',
	'ENABLE_GZIP_EXPLAIN'		=> 'ناوەڕۆکی بەرهەمهاتوو دەپەستێورێ بۆ ناردنی بۆ بەکارهێنەرەکە. ئەمە دەتوانێ ترافیکی ڕایەڵە بگەڕێنێتەوە بەڵام بەکاربردنی CPU سەختر دەکات لەسەر هەردوو ڕاژەکە لەگەڵ تەنیشتە بێ-دەنگ. zlip PHP داوادەکرێ بۆ ئەوەی باربکرێت.',
	'FORCE_SERVER_VARS'	=> 'ڕێکخستنەکانی URL ــی ڕاژە بەهێزبکە',
	'FORCE_SERVER_VARS_EXPLAIN'	=> 'ئەگەر بۆ بەڵێ دانرا ڕێکخستنەکانی ڕاژەی لێرە پێناسکراو بەکاردەبڕی لە  فرەیی خۆکارانەی نرخە دیاریکراوەکان.',
	'ICONS_PATH'	=> 'ڕێچکەی کۆگای ئاکۆنەکانی پەیام',
	'ICONS_PATH_EXPLAIN'	=> 'ڕێچکە لەژێر پێڕستی سەرەتای phpBB ــەکەتە ،نموونە <samp>images/icons</samp>.',
	'PATH_SETTINGS'	=> 'ڕێکخستنەکانی ڕێچکە',
	'RANKS_PATH'	=> 'ڕێچکەی کۆگای پلەی وێنە',
	'RANKS_PATH_EXPLAIN'	=> 'ڕێچکە لەژێر پێڕستی سەرەتای phpBB ــەکەتە ،نموونە <samp>images/ranks</samp>.',
	'SCRIPT_PATH'	=> 'پرۆگرامۆکەی ڕێچکە',
	'SCRIPT_PATH_EXPLAIN'	=> 'ڕێچکەکە کە phpBB کەوتۆتە نێو پەیوەندیدار بۆ ناوە دۆمێینەکە، نموونە <samp>/phpBB3</samp>.',
	'SERVER_NAME'	=> 'ناوە دۆمێین',
	'SERVER_NAME_EXPLAIN'	=> 'ناوە دۆمێینەکەی ئەو مەکۆیە دەڕوات لێوە ،بۆ نموونە <samp>www.example.com</samp>.',
	'SERVER_PORT'	=> 'دەرگای ڕاژە',
	'SERVER_PORT_EXPLAIN'	=> 'ئەو دەرگایەی ڕاژەکە لەسەری دەڕوات ،ئاساییانە 80 ،تەنها گۆڕین ئەگەر جیاوازبێت.',
	'SERVER_PROTOCOL'	=> 'کۆنووسی ڕاژە',
	'SERVER_PROTOCOL_EXPLAIN'	=> 'ئەوە بەکاردەهێنرێت وەکو کۆنووسی ڕاژەکە ئەگەر ئەو ڕێکخستنانە بەهێزکران، ئەگەر بەتاڵ یان بەهێز نەکرا کۆنووسەکە دیاریدەکرێ لەلایەن ڕێکخستنەکانی شەکرۆکە <samp>http://</samp> یان <samp>https://</samp> .',
	'SERVER_URL_SETTINGS'	=> 'ڕێکخستنەکانی URL ــی ڕاژە',
	'SMILIES_PATH'	=> 'ڕێچکەی کۆگای خەندەکان',
	'SMILIES_PATH_EXPLAIN'	=> 'ڕێچکە لەژێر پێڕستی سەرەتای phpBB ــەکەتە ،نموونە <samp>images/smilies</samp>.',
	'UPLOAD_ICONS_PATH'	=> 'ڕێچکەی کۆگای ئایکۆنی گرووپە زیادەکان',
	'UPLOAD_ICONS_PATH_EXPLAIN'	=> 'ڕێچکە لەژێر پێڕستی سەرەتای phpBB ــەکەتە ،نموونە <samp>images/upload_icons</samp>.',
	'ACP_SECURITY_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت دانیشتن پێناسبکەیت لەگەڵ ڕێکخستنە پەیوەندیدارەکانی چوونەژوورەوە.',
	'ALL'	=> 'هەموو',
	'ALLOW_AUTOLOGIN'	=> 'ڕێگابدە بە چوونەژوورەوە بەردەوامەکان',
	'ALLOW_AUTOLOGIN_EXPLAIN'	=> 'دیاریکردنی ئەگەرنا بەکارهێنەران دەتوانن خۆکار بچنەژوورەوە کاتێ ئەوان سەردانی مەکۆکە دەکەن.',
	'AUTOLOGIN_LENGTH'	=> 'درێژی بەسەرچوونی چوونەژوورەوە بەردەوامەکان (لە ڕۆژدا)',
	'AUTOLOGIN_LENGTH_EXPLAIN'	=> 'ژمارەی ڕۆژەکان لەدوای ئەوەی کلیلەکانی چوونەژوورەوەی بەردەوام گواسترانەوە یان 0 بۆ ناچالاککردن.',
	'BROWSER_VALID'	=> 'وێبگەڕی جێگیر',
	'BROWSER_VALID_EXPLAIN'	=> 'بەردەستبوونی وێبگەڕ چالاکبکە بۆ هەر دانیشتنێکی گەشەپێدانی پاراستن.',
	'CHECK_DNSBL'	=> 'لستی ڕەشی IP دژی DNS بپشکنە',
	'CHECK_DNSBL_EXPLAIN'	=> 'ئەگەر چالاککرا ناونیشانی IP بەکارهێنەرەکە دەپشکنرێ دژی ئەو خزمەتگوزارییانەی DNSBL ــی خوارەوە لەسەر تۆماربوون و پەیامکردن: <a href="http://spamcop.net">spamcop.net</a> لەگەڵ <a href="http://www.spamhaus.org">www.spamhaus.org</a> ،ئەو بەدواگەڕانە ئامۆژگاریکراوە بۆ ناچالاککردنی ئەو بپشکنینە.',
	'CLASS_B'	=> 'A.B',
	'CLASS_C'	=> 'A.B.C',
	'EMAIL_CHECK_MX'	=> 'دۆمێنی ئیمەیڵ بپشکنە بۆ تۆماری MX ــی دروست.',
	'EMAIL_CHECK_MX_EXPLAIN'	=> 'ئەگەر چالاککرا ،دۆمێینی ئیمەیڵەکە دەدرێت لە تۆماربوون و گۆڕانکارییەکانی پرۆفایل دەپشکنرێ بۆ تۆمارێکی MX ــی دروست.',
	'FORCE_PASS_CHANGE'	=> 'بەهێزی گۆڕینی تێپەڕەوشە',
	'FORCE_PASS_CHANGE_EXPLAIN'	=> 'بەکارهێنەر ڕاسپێرە بۆ گۆڕینی تێپەڕەوشە لەدوای دانراوێکی ژمارەکان بۆ ڕۆژ. دانانی ئەو نرخە بۆ 0 ئەو ڕەوشتە ناچالاک دەکات.',
	'FORM_TIME_MAX'	=> 'زۆرترین کات بۆ ناردنی فۆرمەکان',
	'FORM_TIME_MAX_EXPLAIN'	=> 'ئەو کاتەی بەکارهێنەرێک پێویستە فۆرمێک بنێرێ. 1- بەکارببە بۆ ناچالاککردن. سەرنجبدە کە فۆرمێک لەوانەیە نادروست بێت ئەگەر دانیشتنەکە بەسەرچوو.',
	'FORM_SID_GUESTS'	=> 'پێچانەوەی فۆرمەکان بۆ دانیشتنەکانی میوان',
	'FORM_SID_GUESTS_EXPLAIN'	=> 'ئەگەر چالاککرا ،فۆرمەکە بۆ کێشە دەبردرێ بۆ میوانان دەبێتە زۆرکردن-دانیشتن .ئەوە دەتوانێ ببێتە هۆی کێشە لەگەڵ هەندێ ISP ــەکان.',
	'FORWARDED_FOR_VALID'	=> 'پێشپەڕەی <var>X_FORWARDED_FOR</var> بەردەستکراو.',
	'FORWARDED_FOR_VALID_EXPLAIN'	=> 'دانیشتنەکان تەنها کاتێ بەردەوام دەبن ئەگەر پێشپەڕەی <var>X_FORWARDED_FOR</var> یەکسان بێت بەو نێردراوەی لەگەڵ داوای پێشوو. ڕاگرتنەکانیش دەپشکنرێن دژی IP ــەکان لە <var>X_FORWARDED_FOR</var>.',
	'IP_VALID'	=> 'بەردەستبوونی IP ــی دانیشتن',
	'IP_VALID_EXPLAIN'	=> 'دیاریکردنی چەند لە IP ــی بەکارهێنەران بەکاردەبرێ بۆ دانیشتنێکی بەردەست؛ <samp>All</samp> دێتەوە لەگەڵ تەواوی ناونیشانەکە، <samp>A.B.C</samp>  یەکەم x.x.x, <samp>A.B</samp> یەکەم x.x <samp>None</samp> پشکنین ناچالاک دەکات. لەسەر ناونیشانەکانی IPv6 <samp>A.B.C</samp> دێتەوە بۆ یەکەم 4 خشتەکان لەگەڵ <samp>A.B</samp> یەکەم 3 خشتەکان.',
	'MAX_LOGIN_ATTEMPTS'	=> ' زۆرترین ژمارەی هەوڵەکانی چوونەژوورەوە بۆهەر ناونیشانێکی IP',
	'MAX_LOGIN_ATTEMPTS_EXPLAIN'	=> 'لەدوای ئەو ژمارەیە لە سەرنەکەوتنی چوونەژوورەوە بەکارهێنەر پێویستە بۆ زیادکراوی ئەزموونی دژە-سپام شیکار بکات.',
	'IP_LOGIN_LIMIT_MAX'			=> ' زۆرترین ژمارەی هەوڵەکانی چوونەژوورەوە بۆهەر ناونیشانێکی IP',
	'IP_LOGIN_LIMIT_MAX_EXPLAIN'	=> 'لەدوای ئەو ژمارەیە لە سەرنەکەوتنی چوونەژوورەوە بەکارهێنەر پێویستە بۆ زیادکراوی ئەزموونی دژە-سپام شیکار بکات.',
	'IP_LOGIN_LIMIT_TIME'			=> 'کاتی بەسەرچوونی هەوڵی چوونەژوورەوەی ناونیشانی IP',
	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'هەوڵەکانی چوونەژوورەوە بەسەردەچن لەدوای ئەم وادەیە ،لە چرکەکان.',
	'IP_LOGIN_LIMIT_USE_FORWARDED'	=> 'هەوڵەکانی چوونەژوورەوە سنوورداربکە بەهۆی پێشڕەوی <var>X_FORWARDED_FOR</var>',
	'IP_LOGIN_LIMIT_USE_FORWARDED_EXPLAIN'	=> 'لەباتی سنووردارکردنی هەوڵەکانی چوونەژوورەوە بەهۆی ناونیشانی IP ئەوان سنووردارکراون بەهۆی نرخەکانی <var>X_FORWARDED_FOR</var>. <br /><em><strong>ئاگاداری:</strong> ئەمە چالاکبکە تەنها ئەگەر ڕاژەیەکی بریکاریی بەگەڕدەخەیت کە <var>X_FORWARDED_FOR</var> دادەنێ بۆ نرخە ڕاستەقینەکان.</em>',
	'MAX_LOGIN_ATTEMPTS'			=> 'زۆرترین ژمارەی هەوڵەکانی چوونەژوورەوە بۆهەر ناوی بەکاهێنەرێک',
	'MAX_LOGIN_ATTEMPTS_EXPLAIN'	=> 'ئەو ژمارەی ڕێگادراوەی هەوڵەکانی چوونەژوورەوە بۆ هەر هەژمارێک لەپێش ئەزموونی دژە-سپام پێکاوە. 0 بنووسە بۆ دوورخستنەوەی ئەزموونی دژە-سپامەکە لە پێکانی بۆ هەژماری بەکارهێنەران.',
	'NO_IP_VALIDATION'	=> 'هیچ',
	'NO_REF_VALIDATION'	=> 'هیچ',
	'PASSWORD_TYPE'	=> 'ئاڵۆزی تێپەڕەوشە',
	'PASSWORD_TYPE_EXPLAIN'	=> 'دیاریکردنی تێپەڕەوشەیەک چەند ئاڵۆزی پێویستە کە دانرا یان گۆڕدرا ،هەڵبژاردنە خێراکان ئەوەی پێشوو لەخۆ دەگرن.',
	'PASS_TYPE_ALPHA'	=> 'دەبێ وشە و ژمارە لەخۆبگرێت',
	'PASS_TYPE_ANY'	=> 'هیچ پێداویستییەک',
	'PASS_TYPE_CASE'	=> 'دەبێت باری تێکەڵ بێت.',
	'PASS_TYPE_SYMBOL'	=> 'دەبێ هێماکان لەخۆی بگرێت',
	'REF_HOST'	=> 'تەنها خانەخوێێ بەردەست',
	'REF_PATH'	=> 'هەروەها ڕێچکەی بەردەستیش',
	'REFERER_VALID'	=> 'ئاماژەکەری بەردەست',
	'REFERER_VALID_EXPLAIN'	=> 'ئەگەر چالاککرا ،داواکانی ئاماژەکەری پەیامەکە دەپشکنرێ دژی ڕێکخستنەکانی ڕێچکەی پرۆگرامۆکە/خانەخوێ. ئەمە لەوانەیە ببێتە هۆی کێشەکان لەگەڵ مەکۆکان بەکاربردنی فرە دۆمێینی لەگەڵ چوونەژوورەوە زۆرزیادەکان.',
	'TPL_ALLOW_PHP'	=> 'ڕێگابدە بە php لە داڕێژەکان',
	'TPL_ALLOW_PHP_EXPLAIN'	=> 'ئەگەر ئەو هەڵبژاردنە چالاککرا <code>PHP</code> لەگەڵ <code>INCLUDEPHP</code> رێکدەخرێن و دەبرێن بۆ داڕێژەکان.',
	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'ئەو زانیارییە بەکارهاتووە لەکاتێ مەکۆکە ئیمەیڵ دەنێرێ بۆ بەکارهێنەرانت. تکایە دڵنیابە ناونیشانی ئەو ئیمەیڵەی دیاریدەکەی دروستە ،هەر وریاکەرەوە و ئاگانامەیەک زۆرتر دەنێردرێت بۆ ئەو ناونیشانە. ئەگەر خانەخوێیەکەت خزمەتگوزاری ئیمەیڵێکی (بنچینەکراوی PHP) نادات دەتوانی پەیامەکان ڕاستەوخۆ بنێری بە بەکارهێنانی SMTP. ئەمە داوای ڕاژەی بەرامبەرکێ دەکات .ئەگەر ڕاژەکە داوای پەسەندکردن دەکات (وە تەنها ئەگەر کردی) ناوی بەکارهێنەری پێویست بنووسە ،تێپەڕەوشە لەگەڵ ڕێگای پەسەندکردن.',
	'ADMIN_EMAIL'	=> 'ناونیشانی ئیمەیڵ بگەڕێنەوە',
	'ADMIN_EMAIL_EXPLAIN'	=> 'ئەمە بەکاردەبرێت وەکو ناونیشانی گەڕانەوە لەسەر هەموو ئیمەیڵەکان ،ناونیشانی ئیمەیڵی تەکنیکی بۆ پەیوەندی. هەمیشە بەکاردەهێنرێت وەکو <samp>Return-Path</samp> لەگەڵ ناونیشانی <samp>Sender</samp> لە ئیمەیڵەکان.',
	'BOARD_EMAIL_FORM'	=> 'بەکارهێنەران ئیمەیڵ لەڕێگای مەکۆ دەنێرن',
	'BOARD_EMAIL_FORM_EXPLAIN'	=> 'لەباتی نیشاندانی ناونیشانی ئیمەیڵی بەکارهێنەران ،بەکارهێنەران دەتوانن ئیمەیڵ بنێرن لە ڕێگای مەکۆوە.',
	'BOARD_HIDE_EMAILS'	=> 'ناونیشانی ئیمەیڵەکان بشارەوە',
	'BOARD_HIDE_EMAILS_EXPLAIN'	=> 'ئەو نەخشەیە ناونیشانی ئیمەیڵەکان تەواو بە نهێنی دەهێڵێتەوە.',
	'CONTACT_EMAIL'	=> 'ناونیشانی ئیمەیڵی پەیوەندی',
	'CONTACT_EMAIL_EXPLAIN'	=> 'ئەو ناونیشانە بەکاردەبرێت لەهەر کوێیەک هەژمارێکی دیاریکراو پێویست بوو ،نموونە سپام ،هەڵەی بەرهەمهاتوو ..هتد هەمیشە بەکاردەبرێت وەکو <samp>From</samp> لەگەڵ ناونیشانانی <samp>Reply-To</samp> لە ئیمەیڵەکان.',
	'EMAIL_FUNCTION_NAME'	=> 'ناوی نەخشەی ئیمەیڵ',
	'EMAIL_FUNCTION_NAME_EXPLAIN'	=> 'نەخشەی ئیمەیڵەکە بەکارهاتووە بۆ ناردنی ئیمەیڵەکان بەناو PHP.',
	'EMAIL_PACKAGE_SIZE'	=> 'قەبارەی گورزەی ئیمەیل',
	'EMAIL_PACKAGE_SIZE_EXPLAIN'	=> 'ئەوە ژمارەی زۆرترین ئیمەیڵە  نێردراوە لە یەک گورزەدا. ئەو ڕێکخستنە سەپێندراوە بۆ پەیامی ناوەکی؛  ئەو نرخە بۆ 0 دابنێ ئەگەر کێشەت هەیە لەگەڵ وریاکەرەوەی پی-نەگەیشتن. ',
	'EMAIL_SIG'	=> 'واژۆی ئیمەیل',
	'EMAIL_SIG_EXPLAIN'	=> 'ئەو دەقە هاوپێچ دەکرێت بۆ هەموو ئەو ئیمەیڵانەی مەکۆکە دەینێرێت.',
	'ENABLE_EMAIL'	=> 'ئیمەیڵی فراوان-مەکۆ چالاکبکە',
	'ENABLE_EMAIL_EXPLAIN'			=> 'ئەگەر ئەوە ناچالاککرا هیچ ئیمەیڵێک نانێردرێ لەلایەن مەکۆکە هەرگیز. <em>سەرنجبدە بەکارهێنەرەکە و ڕێکخستنەکان ،ناچالاککردنی ئەو ڕێکخستنە داوای هیچ چالاککردنێک ناکات بۆ هەژمارە نوێیەکان.</em>',
	'SMTP_AUTH_METHOD'	=> 'ڕێگای پەسەندکراو بۆ SMTP',
	'SMTP_AUTH_METHOD_EXPLAIN'	=> 'تەنها بەکاردەبرێ ئەگەر ناوی بەکارهێنەرێک/تێپەڕەوشەیەک دانرا ،لە پێشخەرەکەت بپرسە ئەگەر دڵنیانیت کام ڕێگا بەکارببەیت.',
	'SMTP_CRAM_MD5'	=> 'CRAM-MD5',
	'SMTP_DIGEST_MD5'	=> 'DIGEST-MD5',
	'SMTP_LOGIN'	=> 'چوونەژوورەوە',
	'SMTP_PASSWORD'	=> 'تێپەڕەوشەی SMTP',
	'SMTP_PASSWORD_EXPLAIN'			=> 'تەنها تێپەڕەوشەیەک بنووسە ئەگەر ڕاژەی SMTP داوای دەکات.<br /><em><strong>ئاگاداری:</strong> ئەو تێپەڕەوشەیە کۆگادەکرێ وەکو دەقی نەخش لە بنکەدراوەکە ،بینراو بۆ هەمووان کە دەتوانێ بگات بە بنکەدراوەکەت یان دەتوانێ پەڕەی دیمەنکردن ببینێ.</em>',
	'SMTP_PLAIN'	=> 'PLAIN',
	'SMTP_POP_BEFORE_SMTP'	=> 'POP-BEFORE-SMTP',
	'SMTP_PORT'	=> 'دەرگای ڕاژەی SMTP',
	'SMTP_PORT_EXPLAIN'	=> 'ئەمە تەنها بگۆڕە ئەگەر دەزانیت ڕاژەی SMTP لەسەر دەرگایەکی جیاوازە.',
	'SMTP_SERVER'	=> 'ناونیشانی ڕاژەی SMTP',
	'SMTP_SETTINGS'	=> 'ڕێکخستنەکانی SMTP',
	'SMTP_USERNAME'	=> 'ناوی بەکارهێنەری SMTP',
	'SMTP_USERNAME_EXPLAIN'	=> 'تەنها ناوی بەکارهێنەرێک بنووسە ئەگەر ڕاژەی SMTP داوای دەکات.',
	'USE_SMTP'	=> 'ڕاژەی SMTP بەکارببە بۆ ئیمەیڵ',
	'USE_SMTP_EXPLAIN'	=> '"بەڵێ" هەڵبژێرە ئەگەر دەتەوێ یان دەبێت ئیمەیڵ بنێریت لەڕێگای ڕاژەیەکی ناوکراو لەباتی نەخشەی ناوخۆ.',
	'ACP_JABBER_SETTINGS_EXPLAIN'	=> 'لێرە دەتوانیت پەیامبەری جابەر چالاک بکەیت بۆ پەیامکردنی ناوکردەیی و ئاگادارکردنەوەکانی مەکۆ. جابەر کۆنووسێکی سەرچاوەکراوەیە و لەمەودوا بەردەستە بۆ بەکارهێنان لەلایەن هەمووکەس. هەندێ ڕاژەی جابەر ڕۆیشتن تێدایە یان گوێزەرەوەکان کە ڕێگات دەدەن پەیوەندی بگریت بۆ هەژماری بەکارهێنەران لەسەر ڕایەڵەکانی تر. هەموو ڕاژەکان گوێزەرەوەی گشتی و گۆڕانکاری کۆنووسەکان پێشکەش ناکەن .تکایە دڵنیابە وردەکاری هەژمارێکی تۆماربوو دەنووسیت - phpBB وردەکارییەکان لێرە وەکو خۆی بەکاردەبات.',
	'JAB_ENABLE'	=> 'جابەر چالاکبکە',
	'JAB_ENABLE_EXPLAIN'	=> 'چالاککردنی سوودی دەبێت بۆ پەیامکردنی جابەر لەگەڵ ئاگادارکەرەوەکان.',
	'JAB_GTALK_NOTE'	=> 'تێبینی چالاکبکە کە GTalk کارناکت چونکە نەخشەی <samp>dns_get_record</samp> ناتوانرێت بدۆزرێتەوە. ئەو نەخشەیە بەردەست نییە لە PHP4 ،وە گونجاو نییە لە سەکۆکانی ویندۆز. ڕاستەوخۆ کارناکات لەسەر سیستەمەکانی بنچینەکراو-BSD ،لەناویاندا Mac OS .',
	'JAB_PACKAGE_SIZE'	=> 'قەبارەی گورزەی جابەر',
	'JAB_PACKAGE_SIZE_EXPLAIN'	=> 'ئەوە ژمارەی پەیامە نێردراوەکانە لە یەک گورزە ،ئەگەر 0 دانرا پەیامەکە ڕاستەوخۆ دەنێردرێت و ناهێڵدرێتەوە بۆن ناردنی دواتر.',
	'JAB_PASSWORD'	=> 'تێپەڕەوشەی جابەر',
	'JAB_PASSWORD_EXPLAIN'		=> '<em><strong>ئاگاداری:</strong> ئەو تێپەڕەوشەیە کۆگادەکرێ وەکو دەقی نەخش لە بنکەدراوەکە و بینراو بۆ هەمووان ئەوەی کە دەتوانێ بگات بە بنکەدراوە یان ئەوەی کە دەتوانێ پەڕەی دیمەنکردن ببینێ.</em>',
	'JAB_PORT'	=> 'دەرچەی جابەر',
	'JAB_PORT_EXPLAIN'	=> 'بەتاڵ جێی بهێڵە ،تەنها ئەگەر دەزانی ئەوە دەرگای 5222 نییە.',
	'JAB_SERVER'	=> 'ڕاژەکاری جابەر',
	'JAB_SERVER_EXPLAIN'	=> 'بۆ لیستێکی ڕاژەکان %sjabber.org%s ببینە.',
	'JAB_SETTINGS_CHANGED'	=> 'بەسەرکەوتوویی ڕێکخستنەکانی جابەر گۆڕا.',
	'JAB_USE_SSL'	=> 'بۆ پەیوەندی SSL بەکارببە',
	'JAB_USE_SSL_EXPLAIN'	=> 'ئەگەر پەیوەندی گرتنی پارێزراو چالاککرا و هەوڵدرا بۆ گرتنی. دەرگای جابەر دڵنیادەکرێتەوە بۆ 5223 ئەگەر دەرگای 5222 دیاریکرابێت.',
	'JAB_USERNAME'	=> 'ناوی بەکارهێنەری جابەر یان JID',
	'JAB_USERNAME_EXPLAIN'	=> 'ناوی بەکارهێنەرێکی تۆماربوو دیاریبکە یان JID ــێکی دروست. ناوی بەکارهێنەرەکە ناپشکنرێت بۆ دروستیی. ئەگەر تۆ تەنها ناوی بەکارهێنەرێک دیاریبکەی. ئەوکات JID ــەکەت دەبێتە ناوی بەکارهێنەر و ڕاژەکەش کە لەسەرەوە دیاریت کردووە. یانیش JID ــێکی دروست دیاریبکە ،بۆ نموونە user@jabber.org.',
));

?>
